#ifndef _EFL_CANVAS_VG_GRADIENT_LINEAR_EO_H_
#define _EFL_CANVAS_VG_GRADIENT_LINEAR_EO_H_

#ifndef _EFL_CANVAS_VG_GRADIENT_LINEAR_EO_CLASS_TYPE
#define _EFL_CANVAS_VG_GRADIENT_LINEAR_EO_CLASS_TYPE

typedef Eo Efl_Canvas_Vg_Gradient_Linear;

#endif

#ifndef _EFL_CANVAS_VG_GRADIENT_LINEAR_EO_TYPES
#define _EFL_CANVAS_VG_GRADIENT_LINEAR_EO_TYPES


#endif
#ifdef EFL_BETA_API_SUPPORT
/** Efl vector graphics gradient linear class
 *
 * @ingroup Efl_Canvas_Vg_Gradient_Linear
 */
#define EFL_CANVAS_VG_GRADIENT_LINEAR_CLASS efl_canvas_vg_gradient_linear_class_get()

EWAPI const Efl_Class *efl_canvas_vg_gradient_linear_class_get(void) EINA_CONST;
#endif /* EFL_BETA_API_SUPPORT */

#endif
